@@ -1,12 +1,15 @@
 /*----------------------------------------------------------------------------------
 Name               : main.c
 Author             : Marvin Raaijmakers
-Description        : The main source file of keytouchd, that contains the
-                     event-loop. This program grabs the key press events of the
-                     extra function keys and performs the appropriate action when
-                     such key is pressed.
-Date of last change: 21-Sep-2006
-History            : 21-Sep-2006 Added support for IBM/Lenovo notebooks (modified
+Description        : The main source file of keytouchd-acpid, that catches events
+                     from the ACPI socket file. If such event appears in the
+                     keyboard file of the current keyboard, then this program will
+                     emulate a key event with the specified keycode. This is done by
+                     writing events to the event device of a keyboard.
+Date of last change: 27-Dec-2006
+History            : 27-Dec-2006 This program is not an X client anymore. Instead it
+                                 writes events to the event device of a keyboard.
+                     21-Sep-2006 Added support for IBM/Lenovo notebooks (modified
                                  read_event())
                      03-Jan-2006 - Added signalhandler clean_exit()
                                  - Runs clear_acpi_key_list() when the current
@@ -35,21 +38,22 @@ History            : 21-Sep-2006 Added support for IBM/Lenovo notebooks (modifie
 ------------------------------------------------------------------------------------*/
 #include <stdio.h>
 #include <string.h>
-#include <X11/Xlib.h>
-#include <X11/extensions/XTest.h>
 #include <signal.h>
 #include <sys/wait.h>
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <X11/XF86keysym.h>
+#include <linux/input.h>
 
 #include <mxml.h>
 #include <keytouch-acpid.h>
 #include "ud_socket.h"
 
+#define TestBit(bit, array) (array[(bit) / 8] & (1 << ((bit) % 8)))
 
+
+static int find_keyboard (void);
 static char *read_line (int fd);
 static char *read_event (int fd);
 static void clean_exit (int sig);
@@ -59,42 +63,33 @@ static void clean_exit (int sig);
  */
 static KTAcpiKeyList	key_list;
 static KTKeyboardName	keyboard_name;
-static Display		*display;
+static int		keyboard_fd;
 
 
 int
 main (int argc, char *argv[])
 {
 	KTKeyboardName	tmp_keyboard_name;
-	int		sock_fd, i;
+	int		sock_fd;
 	unsigned int	keycode,
 			nerrs = 0;
 	char		*event_descr;
-	
+	struct input_event event;
 	
 	/* Open the acpi socket */
-	sock_fd = ud_connect(ACPI_SOCKETFILE);
+	sock_fd = ud_connect (ACPI_SOCKETFILE);
 	if (sock_fd < 0)
 	{
-		fprintf (stderr, "%s: can't open socket %s: %s\n",
-			 argv[0], ACPI_SOCKETFILE, strerror(errno));
-		return (EXIT_FAILURE);
+		/*fprintf (stderr, "%s: can't open socket %s: %s\n",
+		         argv[0], ACPI_SOCKETFILE, strerror(errno));*/
+		return EXIT_SUCCESS;
 	}
-	fcntl(sock_fd, F_SETFD, FD_CLOEXEC);
+	fcntl (sock_fd, F_SETFD, FD_CLOEXEC);
 	
-	/* Connect to the server specified in the DISPLAY environment variable */
-	display = XOpenDisplay(NULL);
-	if (display == NULL)
+	keyboard_fd = find_keyboard();
+	if (keyboard_fd == 0) /* If no keyboard was found */
 	{
-		KTError ("Cannot connect to X server %s.", XDisplayName(NULL));
-		return (EXIT_FAILURE);
-	}
-	/* We need the XTest extension to send keyboard events */
-	if (!XQueryExtension (display, "XTEST", &i, &i, &i))
-	{
-		KTError ("Extension XTest unavailable on display '%s'.\n", XDisplayName(NULL));
-		XCloseDisplay (display);
-		return (EXIT_FAILURE);
+		return EXIT_SUCCESS;
 	}
 	
 	get_current_keyboard (&keyboard_name);
@@ -130,13 +125,19 @@ main (int argc, char *argv[])
 				XmlFree (tmp_keyboard_name.manufacturer);
 			}
 			
-			keycode = get_keycode(event_descr, &key_list);
+			keycode = get_keycode (event_descr, &key_list);
 			/* Is the event bound to a keycode? */
 			if (keycode)
 			{
-				XTestFakeKeyEvent(display, keycode, True, 0);
-				XTestFakeKeyEvent(display, keycode, False, 0);
-				XFlush (display);
+				event.type = EV_KEY;
+				event.code = keycode;
+				event.value = 1; /* Pressed */
+				write (keyboard_fd, &event, sizeof event);
+				
+				event.type = EV_KEY;
+				event.code = keycode;
+				event.value = 0; /* Released */
+				write (keyboard_fd, &event, sizeof event);
 			}
 		}
 		else if (errno == EPIPE)
@@ -153,6 +154,61 @@ main (int argc, char *argv[])
 }
 
 
+int
+find_keyboard (void)
+/*
+Input:
+	-
+Output:
+	-
+Returns:
+	A filedescriptor of the opened keyboard event device. If no such device was
+	found then 0 will be returned.
+Description:
+	find_keyboard() searches an event device of a keyboard, named
+	"/dev/input/eventX" (where X is an integer < 32), and returns a
+	filedescriptor of the opened event device if found. If there is more than
+	one keyboard event device, then the event device "/dev/input/eventX" with X
+	as low as possible will be opened.
+*/
+{
+	int evdev_num, keycode;
+	int fd;
+	char filename[] = "/dev/input/eventXXX";
+	char key_bitmask[(KEY_MAX + 7) / 8];
+	
+	for (evdev_num = 0; evdev_num < 32; evdev_num++)
+	{
+		snprintf (filename, sizeof(filename), "/dev/input/event%d", evdev_num);
+		
+		fd = open (filename, O_RDWR);
+		if (fd != -1)
+		{
+			ioctl (fd, EVIOCGBIT(EV_KEY, sizeof(key_bitmask)), key_bitmask);
+			
+			/* For all keycodes: */
+			for (keycode = 0; keycode < BTN_MISC; keycode++)
+			{
+				/* Check if the event device has 'keycode' enabled */
+				if (TestBit (keycode, key_bitmask))
+				{
+					break;
+				}
+			}
+			
+			if (keycode < BTN_MISC) /* If a key was found on this device */
+			{
+				return fd;
+			}
+			close (fd);
+		}
+	}
+        return 0;
+}
+
+
+
+
 void
 clean_exit (int sig)
 /*
@@ -173,7 +229,6 @@ Description:
 	XmlFree (keyboard_name.model);
 	XmlFree (keyboard_name.manufacturer);
 	clear_acpi_key_list (&key_list);
-	XCloseDisplay (display);
 	
 	exit (EXIT_SUCCESS);
 }
