@@ -2,7 +2,16 @@
 Name               : callbacks.c
 Author             : Marvin Raaijmakers
 Description        : Handles the GUI callbacks
-Date of last change: 21-May-2006
+Date of last change: 03-Feb-2007
+History            : 03-Feb-2007 - The action member of a KTKeySettings is now
+                                   modified by using a function of
+                                   key_settings.(c/h)
+                                 - on_plugin_remove_button_clicked():
+                                   kslist_update_plugin_removal() is called before
+                                   removing the plugin
+                     15-Oct-2006 The contents of the 'preferences' structure will
+                                 now only be updates when the "Apply" or "OK"
+                                 button is pressed.
                      02-May-2006 Removed get_selected_key(), global variable
                                  selected_key is now used instead
                      01-May-2006 The KGUI_*() macros are now used instead of
@@ -11,7 +20,7 @@ Date of last change: 21-May-2006
                      23-Apr-2006 Strings that are allocated by gtk_tree_model_get()
                                  are now freed with g_free()
 
-    Copyright (C) 2005-2006 Marvin Raaijmakers
+    Copyright (C) 2005-2007 Marvin Raaijmakers
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -199,6 +208,7 @@ on_plugin_remove_button_clicked        (GtkButton       *button,
 		/* If the user pressed the "Yes"-button */
 		if (response == GTK_RESPONSE_YES)
 		{
+			kslist_update_plugin_removal (&key_list, plugini_get_name (plugin));
 			remove_plugin (plugin, &plugin_list);
 			reload_plugin_treeview (KTGUI_plugin_treeview(), &plugin_list);
 			reload_plugin_list (KTGUI_plugin_combo_list(),
@@ -239,78 +249,6 @@ on_plugin_import_button_clicked        (GtkButton       *button,
 }
 
 
-void
-on_documents_entry_changed             (GtkEditable     *editable,
-                                        gpointer         user_data)
-{
-	if (preferences.documents_dir != NULL)
-	{
-		free (preferences.documents_dir);
-	}
-	preferences.documents_dir = keytouch_strdup (gtk_entry_get_text(GTK_ENTRY(editable)));
-}
-
-
-void
-on_home_page_entry_changed             (GtkEditable     *editable,
-                                        gpointer         user_data)
-{
-	if (preferences.home_page != NULL)
-	{
-		free (preferences.home_page);
-	}
-	preferences.home_page = keytouch_strdup (gtk_entry_get_text(GTK_ENTRY(editable)));
-}
-
-
-void
-on_search_page_entry_changed           (GtkEditable     *editable,
-                                        gpointer         user_data)
-{
-	if (preferences.search_page != NULL)
-	{
-		free (preferences.search_page);
-	}
-	preferences.search_page = keytouch_strdup (gtk_entry_get_text(GTK_ENTRY(editable)));
-}
-
-
-void
-on_browser_entry_changed               (GtkEditable     *editable,
-                                        gpointer         user_data)
-{
-	if (preferences.browser != NULL)
-	{
-		free (preferences.browser);
-	}
-	preferences.browser = keytouch_strdup (gtk_entry_get_text(GTK_ENTRY(editable)));
-}
-
-
-void
-on_email_prog_entry_changed            (GtkEditable     *editable,
-                                        gpointer         user_data)
-{
-	if (preferences.email_program != NULL)
-	{
-		free (preferences.email_program);
-	}
-	preferences.email_program = keytouch_strdup (gtk_entry_get_text(GTK_ENTRY(editable)));
-}
-
-
-void
-on_chat_entry_changed                  (GtkEditable     *editable,
-                                        gpointer         user_data)
-{
-	if (preferences.chat_program != NULL)
-	{
-		free (preferences.chat_program);
-	}
-	preferences.chat_program = keytouch_strdup (gtk_entry_get_text(GTK_ENTRY(editable)));
-}
-
-
 void
 on_email_prog_choose_button_clicked    (GtkButton       *button,
                                         gpointer         user_data)
@@ -375,10 +313,44 @@ on_help_button_clicked                 (GtkButton       *button,
  *          CALLBACKS FOR THE BUTTONS AT THE BOTTOM OF THE MAIN WINDOW         *
  *******************************************************************************/
 
+void
+get_preferences (KTPreferences *prefs)
+/*
+Input:
+	All widgets that contain preferences.
+Output:
+	prefs	- Filled with the preferences read from the widgets of the GUI.
+*/
+{
+	free (prefs->chat_program);
+	prefs->chat_program = keytouch_strdup (gtk_entry_get_text( KTGUI_chat_entry() ));
+	
+	free (prefs->email_program);
+	prefs->email_program = keytouch_strdup (gtk_entry_get_text( KTGUI_email_prog_entry() ));
+	
+	free (prefs->browser);
+	prefs->browser = keytouch_strdup (gtk_entry_get_text( KTGUI_browser_entry() ));
+	
+	free (prefs->home_page);
+	prefs->home_page = keytouch_strdup (gtk_entry_get_text( KTGUI_home_page_entry() ));
+	
+	free (prefs->search_page);
+	prefs->search_page = keytouch_strdup (gtk_entry_get_text( KTGUI_search_page_entry() ));
+	
+	free (prefs->mixer_channel);
+	prefs->mixer_channel = gtk_combo_box_get_active_text ( KTGUI_mixer_channel_combobox() );
+	if (prefs->mixer_channel == NULL)
+	{
+		prefs->mixer_channel = keytouch_strdup ("");
+	}
+}
+
+
 void
 on_ok_button_clicked                   (GtkButton       *button,
                                         gpointer         user_data)
 {
+	get_preferences (&preferences);
 	write_configuration (&key_list, &current_keyboard_name);
 	write_preferences (&preferences);
 	system ("killall keytouchd");
@@ -393,6 +365,7 @@ void
 on_apply_button_clicked                (GtkButton       *button,
                                         gpointer         user_data)
 {
+	get_preferences (&preferences);
 	write_configuration (&key_list, &current_keyboard_name);
 	write_preferences (&preferences);
 	system ("killall keytouchd");
@@ -488,7 +461,7 @@ Description:
 			/* Select the key in the linked list */
 			selected_key = find_key_settings(key_name, &key_list);
 			/* Read the settings of the key */
-			if (!memcmp(&selected_key->action, &selected_key->default_action, sizeof(KTAction)))
+			if (ks_action_is_default (selected_key))
 			{
 				radiobutton = default_radiobutton;
 			}
@@ -535,8 +508,8 @@ Description:
 				else
 				{
 					default_action = (char *)g_strdup_printf ("%s - %s",
-							selected_key->default_action.plugin.plugin_name,
-							selected_key->default_action.plugin.function_name);
+					                  selected_key->default_action.plugin.plugin_name,
+					                  selected_key->default_action.plugin.function_name);
 				}
 			}
 			else if (selected_key->default_action.type == KTActionTypeProgram)
@@ -585,8 +558,7 @@ Global output:
 	/* If a key was selected and the default radiobutton was toggled*/
 	if (selected_key != NULL && gtk_toggle_button_get_active(togglebutton))
 	{
-		clear_key_settings_action (selected_key);
-		selected_key->action = selected_key->default_action;
+		ks_set_to_default (selected_key);
 	}
 }
 
@@ -616,17 +588,15 @@ Description:
 	/* If program_radiobutton is pressed and a key is selected */
 	if ( gtk_toggle_button_get_active (program_radiobutton) && selected_key )
 	{
-		clear_key_settings_action (selected_key);
 		/* Get the text of the program entry */
 		command = (char *) gtk_entry_get_text (program_entry);
 		if (command[0] == '\0') /* If the entry does not contain text */
 		{
-			selected_key->action = selected_key->default_action;
+			ks_set_to_default (selected_key);
 		}
 		else
 		{
-			selected_key->action.type = KTActionTypeProgram;
-			selected_key->action.program.command = keytouch_strdup (command);
+			ks_set_program (selected_key, command);
 		}
 	}
 }
@@ -696,10 +666,7 @@ Description:
 	function_name = (char *) gtk_entry_get_text( KTGUI_plugin_function_combo_entry() );
 	if (plugin_name[0] != '\0' && function_name[0] != '\0' && selected_key)
 	{
-		clear_key_settings_action (selected_key);
-		selected_key->action.type = KTActionTypePlugin;
-		selected_key->action.plugin.plugin_name = keytouch_strdup (plugin_name);
-		selected_key->action.plugin.function_name = keytouch_strdup (function_name);
+		ks_set_plugin (selected_key, plugin_name, function_name);
 	}
 	/* Block the signal handler of and special_action_radiobutton */
 	g_signal_handlers_block_by_func (GTK_OBJECT(special_action_radiobutton), (void *)on_special_action_radiobutton_toggled, NULL);
