@@ -2,8 +2,12 @@
 Name               : config.c
 Author             : Marvin Raaijmakers
 Description        : Reads and writes the configuration files
-Date of last change: 16-Jun-2006
-History            : 16-Jun-2006 Modified the following functions so that they do
+Date of last change: 15-Oct-2006
+History            : 15-Oct-2006 Modified read_preferences() and
+                                 write_preferences() so that they read/writer the
+                                 'mixer_channel' element instead of the
+                                 'documents_dir' element.
+                     16-Jun-2006 Modified the following functions so that they do
                                  not exit the program when a config file is
                                  invalid:
                                  - get_current_keyboard()
@@ -471,7 +475,7 @@ Desciption:
 		else
 		{
 			KTError (_("The keyboard configuration file contains a key, named "
-				"\'%s\', which does not appear in the keyboard file."), key_name);
+			           "\'%s\', which does not appear in the keyboard file."), key_name);
 		}
 		XmlFree (key_name);
 	}
@@ -615,14 +619,14 @@ Desciption:
 	XmlDocument	*document;
 	char		*file_name;
 	XmlElementType	*preferences_type,
-			*documents_dir_type,
+			*mixer_channel_type,
 			*home_page_type,
 			*search_page_type,
 			*browser_type,
 			*email_program_type,
 			*chat_program_type;
 	XmlContent	*preferences_element,
-			*documents_dir_element,
+			*mixer_channel_element,
 			*home_page_element,
 			*search_page_element,
 			*browser_element,
@@ -636,7 +640,7 @@ Desciption:
 	    (preferences_type = XmlGetElementType(ELEM_TYPE_PREFERENCES, document, FALSE)) == NULL ||
 	    (preferences_element = XmlGetElementOfType(XmlDocumentContentList(document), preferences_type, 0)) == NULL)
 	{
-		preferences->documents_dir = keytouch_strdup (PREF_DEFAULT_DOC_DIR);
+		preferences->mixer_channel = keytouch_strdup (PREF_DEFAULT_MIXER_CHANNEL);
 		preferences->home_page = keytouch_strdup (PREF_DEFAULT_HOME_PAGE);
 		preferences->search_page = keytouch_strdup (PREF_DEFAULT_SEARCH_PAGE);
 		preferences->browser = keytouch_strdup (PREF_DEFAULT_BROWSER);
@@ -646,15 +650,15 @@ Desciption:
 	}
 	else
 	{
-		if ((documents_dir_type = XmlGetElementType(ELEM_TYPE_DOCUMENTSDIR, document, FALSE)) == NULL ||
-		    (documents_dir_element =
-		     XmlGetElementOfType(XmlElementContentList(preferences_element), documents_dir_type, 0)) == NULL)
+		if ((mixer_channel_type = XmlGetElementType(ELEM_TYPE_MIXERCHANNEL, document, FALSE)) == NULL ||
+		    (mixer_channel_element =
+		     XmlGetElementOfType(XmlElementContentList(preferences_element), mixer_channel_type, 0)) == NULL)
 		{
-			preferences->documents_dir = keytouch_strdup (PREF_DEFAULT_DOC_DIR);
+			preferences->mixer_channel = keytouch_strdup (PREF_DEFAULT_MIXER_CHANNEL);
 		}
 		else
 		{
-			preferences->documents_dir = XmlGetElementString(documents_dir_element, "");
+			preferences->mixer_channel = XmlGetElementString (mixer_channel_element, "");
 		}
 		if ((home_page_type = XmlGetElementType(ELEM_TYPE_HOMEPAGE, document, FALSE)) == NULL ||
 		    (home_page_element =
@@ -773,7 +777,7 @@ Desciption:
 	element_type = XmlGetElementType(ELEM_TYPE_PREFERENCES, document, TRUE);
 	preferences_element = XmlCreateElement(element_type, FALSE);
 	
-	add_preference (ELEM_TYPE_DOCUMENTSDIR, preferences->documents_dir, preferences_element, document);
+	add_preference (ELEM_TYPE_MIXERCHANNEL, preferences->mixer_channel, preferences_element, document);
 	add_preference (ELEM_TYPE_HOMEPAGE, preferences->home_page, preferences_element, document);
 	add_preference (ELEM_TYPE_SEARCHPAGE, preferences->search_page, preferences_element, document);
 	add_preference (ELEM_TYPE_BROWSER, preferences->browser, preferences_element, document);
