@@ -2,14 +2,15 @@
 Name               : keytouch.h
 Author             : Marvin Raaijmakers
 Description        : The main headerfile for the keytouch configuration program
-Date of last change: 21-Sep-2006
+Date of last change: 19-Mar-2007
 History            :
+                     15-Oct-2006 Replaced the 'documents_dir' member of the
+                                 KTPreferences type by the 'mixer_channel' member.
                      09-Feb-2006 Modified PLUGIN_DIR
                      23-Jan-2006 Added prototype for global _home_dir
-                     17-Jan-2006 Changed VERSION to "2.1.0 beta"
                      02-Jan-2006 Added #include <config.h>
 
-    Copyright (C) 2005-2006 Marvin Raaijmakers
+    Copyright (C) 2005-2007 Marvin Raaijmakers
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -74,7 +75,7 @@ History            :
 #include <gnome-menus/gmenu-tree.h>
 
 
-#define VERSION ("2.2.2")
+#define VERSION ("2.3.0")
 
 #define KEYTOUCH_CONF_DIR		SYSCONF_DIR "/keytouch"
 #define KEYTOUCH_DATA_DIR		PACKAGE_DATA_DIR "/keytouch"
@@ -95,7 +96,7 @@ History            :
 #define kbname_model(_keyboard_name)		((_keyboard_name)->model)
 #define kbname_manufacturer(_keyboard_name)	((_keyboard_name)->manufacturer)
 
-#define PREF_DEFAULT_DOC_DIR		"~/Documents"
+#define PREF_DEFAULT_MIXER_CHANNEL	"Master"
 #define PREF_DEFAULT_HOME_PAGE		"http://keytouch.sf.net"
 #define PREF_DEFAULT_SEARCH_PAGE	"http://www.google.com"
 #define PREF_DEFAULT_BROWSER		""
@@ -148,7 +149,7 @@ typedef struct {
 
 
 typedef struct {
-	char	*documents_dir,
+	char	*mixer_channel,
 		*home_page,
 		*search_page,
 		*browser,
