@@ -29,11 +29,13 @@ History            : 07-Feb-2006 Added definition of MSGQ_AMIXER_PROJ_ID
 #define MSGQ_PERMISSIONS	0600
 #define MSGQ_AMIXER_PROJ_ID	'm'
 
-#define CHANGE_VOL_CMD(_vol)	("amixer set Master " _vol " > /dev/null")
-#define VOL_DEFAULT_INCR	"2%+"
-#define VOL_DEFAULT_DECR	"2%-"
-#define VOL_10PERCENT_INCR	"10%+"
-#define VOL_10PERCENT_DECR	"10%-"
+#define VOLUME_WINDOW_HEIGHT	25
+#define VOLUME_WINDOW_WIDTH	230
+
+#define VOL_DEFAULT_INCR	(2)
+#define VOL_DEFAULT_DECR	(-2)
+#define VOL_10PERCENT_INCR	(10)
+#define VOL_10PERCENT_DECR	(-10)
 
 static char *get_keytouch_user_dir (void);
 
@@ -46,6 +48,7 @@ typedef struct {
 	GtkWidget	*window,
 			*volume_bar;
 	time_t		close_time;
+	const char	*mix_elem_name;
 	int		msgqid;
 } VOLUMEBAR_INFO; 
 
